pub struct FlussAdmin { /* private fields */ }Implementations
Sourceimpl FlussAdmin
impl FlussAdmin
pub fn new(connections: Arc<RpcClient>, metadata: Arc<Metadata>) -> Self
pub async fn create_database( &self, database_name: &str, database_descriptor: Option<&DatabaseDescriptor>, ignore_if_exists: bool, ) -> Result<()>
pub async fn create_table( &self, table_path: &TablePath, table_descriptor: &TableDescriptor, ignore_if_exists: bool, ) -> Result<()>
pub async fn drop_table( &self, table_path: &TablePath, ignore_if_not_exists: bool, ) -> Result<()>
pub async fn get_table_info(&self, table_path: &TablePath) -> Result<TableInfo>
Sourcepub async fn list_tables(&self, database_name: &str) -> Result<Vec<String>>
pub async fn list_tables(&self, database_name: &str) -> Result<Vec<String>>
List all tables in the given database
Sourcepub async fn list_partition_infos(
&self,
table_path: &TablePath,
) -> Result<Vec<PartitionInfo>>
pub async fn list_partition_infos( &self, table_path: &TablePath, ) -> Result<Vec<PartitionInfo>>
List all partitions in the given table.
Sourcepub async fn list_partition_infos_with_spec(
&self,
table_path: &TablePath,
partial_partition_spec: Option<&PartitionSpec>,
) -> Result<Vec<PartitionInfo>>
pub async fn list_partition_infos_with_spec( &self, table_path: &TablePath, partial_partition_spec: Option<&PartitionSpec>, ) -> Result<Vec<PartitionInfo>>
List partitions in the given table that match the partial partition spec.
Sourcepub async fn create_partition(
&self,
table_path: &TablePath,
partition_spec: &PartitionSpec,
ignore_if_exists: bool,
) -> Result<()>
pub async fn create_partition( &self, table_path: &TablePath, partition_spec: &PartitionSpec, ignore_if_exists: bool, ) -> Result<()>
Create a new partition for a partitioned table.
Sourcepub async fn drop_partition(
&self,
table_path: &TablePath,
partition_spec: &PartitionSpec,
ignore_if_not_exists: bool,
) -> Result<()>
pub async fn drop_partition( &self, table_path: &TablePath, partition_spec: &PartitionSpec, ignore_if_not_exists: bool, ) -> Result<()>
Drop a partition from a partitioned table.
Sourcepub async fn table_exists(&self, table_path: &TablePath) -> Result<bool>
pub async fn table_exists(&self, table_path: &TablePath) -> Result<bool>
Check if a table exists
Sourcepub async fn drop_database(
&self,
database_name: &str,
ignore_if_not_exists: bool,
cascade: bool,
) -> Result<()>
pub async fn drop_database( &self, database_name: &str, ignore_if_not_exists: bool, cascade: bool, ) -> Result<()>
Drop a database
Sourcepub async fn list_databases(&self) -> Result<Vec<String>>
pub async fn list_databases(&self) -> Result<Vec<String>>
List all databases
Sourcepub async fn database_exists(&self, database_name: &str) -> Result<bool>
pub async fn database_exists(&self, database_name: &str) -> Result<bool>
Check if a database exists
Sourcepub async fn get_database_info(
&self,
database_name: &str,
) -> Result<DatabaseInfo>
pub async fn get_database_info( &self, database_name: &str, ) -> Result<DatabaseInfo>
Get database information
Sourcepub async fn get_server_nodes(&self) -> Result<Vec<ServerNode>>
pub async fn get_server_nodes(&self) -> Result<Vec<ServerNode>>
Get all alive server nodes in the cluster, including the coordinator and all tablet servers. Refreshes cluster metadata before returning.
Sourcepub async fn get_latest_lake_snapshot(
&self,
table_path: &TablePath,
) -> Result<LakeSnapshot>
pub async fn get_latest_lake_snapshot( &self, table_path: &TablePath, ) -> Result<LakeSnapshot>
Get the latest lake snapshot for a table
Sourcepub async fn list_offsets(
&self,
table_path: &TablePath,
buckets_id: &[BucketId],
offset_spec: OffsetSpec,
) -> Result<HashMap<i32, i64>>
pub async fn list_offsets( &self, table_path: &TablePath, buckets_id: &[BucketId], offset_spec: OffsetSpec, ) -> Result<HashMap<i32, i64>>
List offset for the specified buckets. This operation enables to find the beginning offset, end offset as well as the offset matching a timestamp in buckets.
Sourcepub async fn list_partition_offsets(
&self,
table_path: &TablePath,
partition_name: &str,
buckets_id: &[BucketId],
offset_spec: OffsetSpec,
) -> Result<HashMap<i32, i64>>
pub async fn list_partition_offsets( &self, table_path: &TablePath, partition_name: &str, buckets_id: &[BucketId], offset_spec: OffsetSpec, ) -> Result<HashMap<i32, i64>>
List offset for the specified buckets in a partition. This operation enables to find the beginning offset, end offset as well as the offset matching a timestamp in buckets.