UpsertWriter

Struct UpsertWriter 

pub struct UpsertWriter { /* private fields */ }

Implementations

Source

impl UpsertWriter

pub async fn flush(&self) -> Result<()>

Flush data written that have not yet been sent to the server, forcing the client to send the requests to server and blocks on the completion of the requests associated with these records. A request is considered completed when it is successfully acknowledged according to the CLIENT_WRITER_ACKS configuration option you have specified or else it results in an error.

pub fn upsert<R: InternalRow>(&self, row: &R) -> Result<WriteResultFuture>

Inserts row into Fluss table if they do not already exist, or updates them if they do exist.

This method returns a WriteResultFuture immediately after queueing the write, enabling fire-and-forget semantics for efficient batching.

Arguments
  • row - the row to upsert.
Returns

A WriteResultFuture that can be awaited to wait for server acknowledgment, or dropped for fire-and-forget behavior (use flush() to ensure delivery).

pub fn delete<R: InternalRow>(&self, row: &R) -> Result<WriteResultFuture>

Delete certain row by the input row in Fluss table, the input row must contain the primary key.

This method returns a WriteResultFuture immediately after queueing the delete, enabling fire-and-forget semantics for efficient batching.

Arguments
  • row - the row to delete (must contain the primary key fields).
Returns

A WriteResultFuture that can be awaited to wait for server acknowledgment, or dropped for fire-and-forget behavior (use flush() to ensure delivery).