pub struct DataTypes;Implementations
Sourceimpl DataTypes
impl DataTypes
pub fn binary(length: usize) -> DataType
pub const fn bytes() -> DataType
pub fn boolean() -> DataType
pub fn int() -> DataType
Sourcepub fn tinyint() -> DataType
pub fn tinyint() -> DataType
Data type of a 1-byte signed integer with values from -128 to 127.
Sourcepub fn smallint() -> DataType
pub fn smallint() -> DataType
Data type of a 2-byte signed integer with values from -32,768 to 32,767.
pub fn bigint() -> DataType
pub fn char(length: u32) -> DataType
Sourcepub fn decimal(precision: u32, scale: u32) -> DataType
pub fn decimal(precision: u32, scale: u32) -> DataType
Data type of a decimal number with fixed precision and scale DECIMAL(p, s) where
p is the number of digits in a number (=precision) and s is the number of
digits to the right of the decimal point in a number (=scale). p must have a value
between 1 and 38 (both inclusive). s must have a value between 0 and p (both inclusive).
pub fn date() -> DataType
Sourcepub fn time() -> DataType
pub fn time() -> DataType
Data type of a time WITHOUT time zone TIME with no fractional seconds by default.
Sourcepub fn time_with_precision(precision: u32) -> DataType
pub fn time_with_precision(precision: u32) -> DataType
Data type of a time WITHOUT time zone TIME(p) where p is the number of digits
of fractional seconds (=precision). p must have a value between 0 and 9 (both inclusive).
Sourcepub fn timestamp() -> DataType
pub fn timestamp() -> DataType
Data type of a timestamp WITHOUT time zone TIMESTAMP with 6 digits of fractional
seconds by default.
Sourcepub fn timestamp_with_precision(precision: u32) -> DataType
pub fn timestamp_with_precision(precision: u32) -> DataType
Data type of a timestamp WITHOUT time zone TIMESTAMP(p) where p is the number
of digits of fractional seconds (=precision). p must have a value between 0 and 9
(both inclusive).
Sourcepub fn timestamp_ltz() -> DataType
pub fn timestamp_ltz() -> DataType
Data type of a timestamp WITH time zone TIMESTAMP WITH TIME ZONE with 6 digits of
fractional seconds by default.
Sourcepub fn timestamp_ltz_with_precision(precision: u32) -> DataType
pub fn timestamp_ltz_with_precision(precision: u32) -> DataType
Data type of a timestamp WITH time zone TIMESTAMP WITH TIME ZONE(p) where p is the number
of digits of fractional seconds (=precision). p must have a value between 0 and 9 (both inclusive).
Sourcepub fn array(element: DataType) -> DataType
pub fn array(element: DataType) -> DataType
Data type of an array of elements with same subtype.
Sourcepub fn map(key_type: DataType, value_type: DataType) -> DataType
pub fn map(key_type: DataType, value_type: DataType) -> DataType
Data type of an associative array that maps keys to values.
Sourcepub fn field<N: Into<String>>(name: N, data_type: DataType) -> DataField
pub fn field<N: Into<String>>(name: N, data_type: DataType) -> DataField
Field definition with field name and data type.
Sourcepub fn field_with_description<N: Into<String>>(
name: N,
data_type: DataType,
description: String,
) -> DataField
pub fn field_with_description<N: Into<String>>( name: N, data_type: DataType, description: String, ) -> DataField
Field definition with field name, data type, and a description.
Sourcepub fn row_from_types(field_types: Vec<DataType>) -> DataType
pub fn row_from_types(field_types: Vec<DataType>) -> DataType
Data type of a sequence of fields with generated field names (f0, f1, f2, …).