pub struct PartitionSpec { /* private fields */ }Expand description
Represents a partition spec in fluss. Partition columns and values are NOT of strict order, and they need to be re-arranged to the correct order by comparing with a list of strictly ordered partition keys.
Implementations