pub struct ResolvedPartitionSpec { /* private fields */ }Expand description
Represents a partition, which is the resolved version of PartitionSpec. The partition spec is re-arranged into the correct order by comparing it with a list of strictly ordered partition keys.
Implementations
Sourceimpl ResolvedPartitionSpec
impl ResolvedPartitionSpec
pub fn new( partition_keys: Arc<[String]>, partition_values: Vec<String>, ) -> Result<Self>
pub fn from_partition_spec( partition_keys: Arc<[String]>, partition_spec: &PartitionSpec, ) -> Self
pub fn from_partition_name( partition_keys: Arc<[String]>, partition_name: &str, ) -> Self
pub fn from_partition_qualified_name( qualified_partition_name: &str, ) -> Result<Self>
pub fn get_partition_keys(&self) -> &[String]
pub fn get_partition_values(&self) -> &[String]
pub fn to_partition_spec(&self) -> PartitionSpec
Sourcepub fn get_partition_name(&self) -> String
pub fn get_partition_name(&self) -> String
Generate the partition name for a partition table with specified partition values.
The partition name is in the following format: value1$value2$…$valueN
Sourcepub fn get_partition_qualified_name(&self) -> String
pub fn get_partition_qualified_name(&self) -> String
Returns the qualified partition name for a partition spec. The format is: key1=value1/key2=value2/…/keyN=valueN
pub fn contains(&self, other: &ResolvedPartitionSpec) -> Result<bool>
pub fn to_pb(&self) -> PbPartitionSpec
pub fn from_pb(pb: &PbPartitionSpec) -> Self