pub struct SchemaBuilder { /* private fields */ }Implementations
Sourceimpl SchemaBuilder
impl SchemaBuilder
pub fn new() -> Self
pub fn with_row_type(self, row_type: &DataType) -> Self
pub fn column<N: Into<String>>(self, name: N, data_type: DataType) -> Self
pub fn with_columns(self, columns: Vec<Column>) -> Self
pub fn with_comment<C: Into<String>>(self, comment: C) -> Self
pub fn primary_key<I, S>(self, column_names: I) -> Self
pub fn primary_key_named<N: Into<String>, P: Into<String>>( self, constraint_name: N, column_names: Vec<P>, ) -> Self
Sourcepub fn enable_auto_increment<N: Into<String>>(
self,
column_name: N,
) -> Result<Self>
pub fn enable_auto_increment<N: Into<String>>( self, column_name: N, ) -> Result<Self>
Declares a column to be auto-incremented. With an auto-increment column in the table, whenever a new row is inserted into the table, the new row will be assigned with the next available value from the auto-increment sequence. A table can have at most one auto increment column.
pub fn build(&self) -> Result<Schema>