pub struct MetadataRequest {
pub table_path: Vec<PbTablePath>,
pub partitions_path: Vec<PbPhysicalTablePath>,
pub partitions_id: Vec<i64>,
}Expand description
metadata request and response, request send from client to each server.
Fields
table_path: Vec<PbTablePath>partitions_path: Vec<PbPhysicalTablePath>partitions_id: Vec<i64>note: currently, we assume the partition ids must belong to the table_paths in the metadata request todo: we won’t need the assumption after we introduce metadata cache in server