pub struct MetadataResponse {
pub coordinator_server: Option<PbServerNode>,
pub tablet_servers: Vec<PbServerNode>,
pub table_metadata: Vec<PbTableMetadata>,
pub partition_metadata: Vec<PbPartitionMetadata>,
}Fields
coordinator_server: Option<PbServerNode>tablet_servers: Vec<PbServerNode>table_metadata: Vec<PbTableMetadata>partition_metadata: Vec<PbPartitionMetadata>Trait Implementations
Sourceimpl Clone for MetadataResponse
impl Clone for MetadataResponse
Sourcefn clone(&self) -> MetadataResponse
fn clone(&self) -> MetadataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataResponse
impl Debug for MetadataResponse
Sourceimpl Default for MetadataResponse
impl Default for MetadataResponse
Sourceimpl Message for MetadataResponse
impl Message for MetadataResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MetadataResponse
impl PartialEq for MetadataResponse
Sourceimpl<R> ReadVersionedType<R> for MetadataResponsewhere
R: Buf,
impl<R> ReadVersionedType<R> for MetadataResponsewhere
R: Buf,
fn read_versioned( reader: &mut R, _version: ApiVersion, ) -> Result<Self, ReadError>
impl StructuralPartialEq for MetadataResponse