pub enum ChangeType {
AppendOnly,
Insert,
UpdateBefore,
UpdateAfter,
Delete,
}Variants
AppendOnly
Append-only operation
Insert
Insert operation
UpdateBefore
Update operation containing the previous content of the updated row
UpdateAfter
Update operation containing the new content of the updated row
Delete
Delete operation
Implementations
Sourceimpl ChangeType
impl ChangeType
Sourcepub fn short_string(&self) -> &'static str
pub fn short_string(&self) -> &'static str
Returns a short string representation of this ChangeType
Sourcepub fn to_byte_value(&self) -> u8
pub fn to_byte_value(&self) -> u8
Returns the byte value representation used for serialization