Module binary

Module binary 

Enums

BinaryRowFormat
The binary row format types, it indicates the generated row type by the BinaryWriter
InnerValueWriter
ValueWriter

Traits

BinaryWriter
Writer to write a composite data format, like row, array,