pub trait BinaryWriter {
Show 18 methods
// Required methods
fn reset(&mut self);
fn set_null_at(&mut self, pos: usize);
fn write_boolean(&mut self, value: bool);
fn write_byte(&mut self, value: u8);
fn write_bytes(&mut self, value: &[u8]);
fn write_char(&mut self, value: &str, length: usize);
fn write_string(&mut self, value: &str);
fn write_short(&mut self, value: i16);
fn write_int(&mut self, value: i32);
fn write_long(&mut self, value: i64);
fn write_float(&mut self, value: f32);
fn write_double(&mut self, value: f64);
fn write_binary(&mut self, bytes: &[u8], length: usize);
fn write_decimal(&mut self, value: &Decimal, precision: u32);
fn write_time(&mut self, value: i32, precision: u32);
fn write_timestamp_ntz(&mut self, value: &TimestampNtz, precision: u32);
fn write_timestamp_ltz(&mut self, value: &TimestampLtz, precision: u32);
fn complete(&mut self);
}Expand description
Writer to write a composite data format, like row, array,
Required Methods
Sourcefn set_null_at(&mut self, pos: usize)
fn set_null_at(&mut self, pos: usize)
Set null to this field
fn write_boolean(&mut self, value: bool)
fn write_byte(&mut self, value: u8)
fn write_bytes(&mut self, value: &[u8])
fn write_char(&mut self, value: &str, length: usize)
fn write_string(&mut self, value: &str)
fn write_short(&mut self, value: i16)
fn write_int(&mut self, value: i32)
fn write_long(&mut self, value: i64)
fn write_float(&mut self, value: f32)
fn write_double(&mut self, value: f64)
fn write_binary(&mut self, bytes: &[u8], length: usize)
fn write_decimal(&mut self, value: &Decimal, precision: u32)
Sourcefn write_time(&mut self, value: i32, precision: u32)
fn write_time(&mut self, value: i32, precision: u32)
Writes a TIME value.
Note: TIME is physically stored as an i32 (milliseconds since midnight).
This method exists for type safety and semantic clarity, even though it’s
currently equivalent to write_int(). The precision parameter is accepted
for API consistency with TIMESTAMP types, though TIME encoding doesn’t
currently vary by precision.