CompactedKeyWriter

Struct CompactedKeyWriter 

pub struct CompactedKeyWriter { /* private fields */ }
A wrapping of CompactedRowWriter used to encode key columns. The encoding is the same as CompactedRowWriter, but is without header of null bits to represent whether the field value is null or not since the key columns must be not null.

Implementations

Source

impl CompactedKeyWriter

pub fn new() -> CompactedKeyWriter

pub fn create_value_writer(field_type: &DataType) -> Result<ValueWriter>

pub fn reset(&mut self)

pub fn position(&self) -> usize

pub fn buffer(&self) -> &[u8]

pub fn to_bytes(&self) -> Bytes