pub trait KeyEncoder: Send + Sync {
// Required method
fn encode_key(&mut self, row: &dyn InternalRow) -> Result<Bytes>;
}Expand description
An interface for encoding key of row into bytes.
pub trait KeyEncoder: Send + Sync {
// Required method
fn encode_key(&mut self, row: &dyn InternalRow) -> Result<Bytes>;
}An interface for encoding key of row into bytes.