pub struct Decimal { /* private fields */ }Expand description
An internal data structure representing a decimal value with fixed precision and scale.
This data structure is immutable and stores decimal values in a compact representation (as a long value) if values are small enough (precision ≤ 18).
Matches Java’s org.apache.fluss.row.Decimal class.
Implementations
Sourceimpl Decimal
impl Decimal
Sourcepub fn precision(&self) -> u32
pub fn precision(&self) -> u32
Returns the precision of this Decimal.
The precision is the number of digits in the unscaled value.
Sourcepub fn is_compact(&self) -> bool
pub fn is_compact(&self) -> bool
Returns whether the decimal value is small enough to be stored in a long.
Sourcepub fn is_compact_precision(precision: u32) -> bool
pub fn is_compact_precision(precision: u32) -> bool
Returns whether a given precision can be stored compactly.
Sourcepub fn to_big_decimal(&self) -> BigDecimal
pub fn to_big_decimal(&self) -> BigDecimal
Converts this Decimal into a BigDecimal.
Sourcepub fn to_unscaled_long(&self) -> Result<i64>
pub fn to_unscaled_long(&self) -> Result<i64>
Returns a long describing the unscaled value of this Decimal.
Sourcepub fn to_unscaled_bytes(&self) -> Vec<u8> ⓘ
pub fn to_unscaled_bytes(&self) -> Vec<u8> ⓘ
Returns a byte array describing the unscaled value of this Decimal.
Sourcepub fn from_arrow_decimal128(
i128_val: i128,
arrow_scale: i64,
precision: u32,
scale: u32,
) -> Result<Self>
pub fn from_arrow_decimal128( i128_val: i128, arrow_scale: i64, precision: u32, scale: u32, ) -> Result<Self>
Creates a Decimal from Arrow’s Decimal128 representation.
Sourcepub fn from_big_decimal(
bd: BigDecimal,
precision: u32,
scale: u32,
) -> Result<Self>
pub fn from_big_decimal( bd: BigDecimal, precision: u32, scale: u32, ) -> Result<Self>
Creates an instance of Decimal from a BigDecimal with the given precision and scale.
The returned decimal value may be rounded to have the desired scale. The precision will be checked. If the precision overflows, an error is returned.
Sourcepub fn from_unscaled_long(
unscaled_long: i64,
precision: u32,
scale: u32,
) -> Result<Self>
pub fn from_unscaled_long( unscaled_long: i64, precision: u32, scale: u32, ) -> Result<Self>
Creates an instance of Decimal from an unscaled long value with the given precision and scale.
Sourcepub fn from_unscaled_bytes(
unscaled_bytes: &[u8],
precision: u32,
scale: u32,
) -> Result<Self>
pub fn from_unscaled_bytes( unscaled_bytes: &[u8], precision: u32, scale: u32, ) -> Result<Self>
Creates an instance of Decimal from an unscaled byte array with the given precision and scale.
Sourcepub fn compute_precision(unscaled: &BigInt) -> usize
pub fn compute_precision(unscaled: &BigInt) -> usize
Computes the precision of a decimal’s unscaled value, matching Java’s BigDecimal.precision().