pub struct GenericRow<'a> {
pub values: Vec<Datum<'a>>,
}Fields
values: Vec<Datum<'a>>Implementations
Sourceimpl<'a> GenericRow<'a>
impl<'a> GenericRow<'a>
pub fn from_data(data: Vec<impl Into<Datum<'a>>>) -> GenericRow<'a>
Sourcepub fn new(field_count: usize) -> GenericRow<'a>
pub fn new(field_count: usize) -> GenericRow<'a>
Creates a GenericRow with the specified number of fields, all initialized to null.
This is useful when you need to create a row with a specific field count but only want to set some fields (e.g., for KV delete operations where only primary key fields need to be set).
Example
use fluss::row::GenericRow;
let mut row = GenericRow::new(3);
row.set_field(0, 42); // Only set the primary key
// Fields 1 and 2 remain nullTrait Implementations
Sourceimpl<'a> Debug for GenericRow<'a>
impl<'a> Debug for GenericRow<'a>
Sourceimpl<'a> InternalRow for GenericRow<'a>
impl<'a> InternalRow for GenericRow<'a>
Sourcefn get_field_count(&self) -> usize
fn get_field_count(&self) -> usize
Returns the number of fields in this row
Sourcefn is_null_at(&self, pos: usize) -> Result<bool>
fn is_null_at(&self, pos: usize) -> Result<bool>
Returns true if the element is null at the given position
Sourcefn get_boolean(&self, pos: usize) -> Result<bool>
fn get_boolean(&self, pos: usize) -> Result<bool>
Returns the boolean value at the given position
Sourcefn get_double(&self, pos: usize) -> Result<f64>
fn get_double(&self, pos: usize) -> Result<f64>
Returns the double value at the given position
Sourcefn get_char(&self, pos: usize, _length: usize) -> Result<&str>
fn get_char(&self, pos: usize, _length: usize) -> Result<&str>
Returns the string value at the given position with fixed length
Sourcefn get_string(&self, pos: usize) -> Result<&str>
fn get_string(&self, pos: usize) -> Result<&str>
Returns the string value at the given position
Sourcefn get_decimal(
&self,
pos: usize,
_precision: usize,
_scale: usize,
) -> Result<Decimal>
fn get_decimal( &self, pos: usize, _precision: usize, _scale: usize, ) -> Result<Decimal>
Returns the decimal value at the given position
Sourcefn get_date(&self, pos: usize) -> Result<Date>
fn get_date(&self, pos: usize) -> Result<Date>
Returns the date value at the given position (date as days since epoch)
Sourcefn get_time(&self, pos: usize) -> Result<Time>
fn get_time(&self, pos: usize) -> Result<Time>
Returns the time value at the given position (time as milliseconds since midnight)
Sourcefn get_timestamp_ntz(&self, pos: usize, _precision: u32) -> Result<TimestampNtz>
fn get_timestamp_ntz(&self, pos: usize, _precision: u32) -> Result<TimestampNtz>
Returns the timestamp value at the given position (timestamp without timezone) Read more
Sourcefn get_timestamp_ltz(&self, pos: usize, _precision: u32) -> Result<TimestampLtz>
fn get_timestamp_ltz(&self, pos: usize, _precision: u32) -> Result<TimestampLtz>
Returns the timestamp value at the given position (timestamp with local timezone) Read more
Sourcefn get_binary(&self, pos: usize, _length: usize) -> Result<&[u8]>
fn get_binary(&self, pos: usize, _length: usize) -> Result<&[u8]>
Returns the binary value at the given position with fixed length
Sourcefn get_bytes(&self, pos: usize) -> Result<&[u8]>
fn get_bytes(&self, pos: usize) -> Result<&[u8]>
Returns the binary value at the given position
Sourcefn as_encoded_bytes(&self, _write_format: WriteFormat) -> Option<&[u8]>
fn as_encoded_bytes(&self, _write_format: WriteFormat) -> Option<&[u8]>
Returns encoded bytes if already encoded