pub trait InternalRow: Send + Sync {
Show 19 methods
// Required methods
fn get_field_count(&self) -> usize;
fn is_null_at(&self, pos: usize) -> Result<bool>;
fn get_boolean(&self, pos: usize) -> Result<bool>;
fn get_byte(&self, pos: usize) -> Result<i8>;
fn get_short(&self, pos: usize) -> Result<i16>;
fn get_int(&self, pos: usize) -> Result<i32>;
fn get_long(&self, pos: usize) -> Result<i64>;
fn get_float(&self, pos: usize) -> Result<f32>;
fn get_double(&self, pos: usize) -> Result<f64>;
fn get_char(&self, pos: usize, length: usize) -> Result<&str>;
fn get_string(&self, pos: usize) -> Result<&str>;
fn get_decimal(
&self,
pos: usize,
precision: usize,
scale: usize,
) -> Result<Decimal>;
fn get_date(&self, pos: usize) -> Result<Date>;
fn get_time(&self, pos: usize) -> Result<Time>;
fn get_timestamp_ntz(
&self,
pos: usize,
precision: u32,
) -> Result<TimestampNtz>;
fn get_timestamp_ltz(
&self,
pos: usize,
precision: u32,
) -> Result<TimestampLtz>;
fn get_binary(&self, pos: usize, length: usize) -> Result<&[u8]>;
fn get_bytes(&self, pos: usize) -> Result<&[u8]>;
// Provided method
fn as_encoded_bytes(&self, _write_format: WriteFormat) -> Option<&[u8]> { ... }
}Required Methods
Sourcefn get_field_count(&self) -> usize
fn get_field_count(&self) -> usize
Returns the number of fields in this row
Sourcefn is_null_at(&self, pos: usize) -> Result<bool>
fn is_null_at(&self, pos: usize) -> Result<bool>
Returns true if the element is null at the given position
Sourcefn get_boolean(&self, pos: usize) -> Result<bool>
fn get_boolean(&self, pos: usize) -> Result<bool>
Returns the boolean value at the given position
Sourcefn get_double(&self, pos: usize) -> Result<f64>
fn get_double(&self, pos: usize) -> Result<f64>
Returns the double value at the given position
Sourcefn get_char(&self, pos: usize, length: usize) -> Result<&str>
fn get_char(&self, pos: usize, length: usize) -> Result<&str>
Returns the string value at the given position with fixed length
Sourcefn get_string(&self, pos: usize) -> Result<&str>
fn get_string(&self, pos: usize) -> Result<&str>
Returns the string value at the given position
Sourcefn get_decimal(
&self,
pos: usize,
precision: usize,
scale: usize,
) -> Result<Decimal>
fn get_decimal( &self, pos: usize, precision: usize, scale: usize, ) -> Result<Decimal>
Returns the decimal value at the given position
Sourcefn get_date(&self, pos: usize) -> Result<Date>
fn get_date(&self, pos: usize) -> Result<Date>
Returns the date value at the given position (date as days since epoch)
Sourcefn get_time(&self, pos: usize) -> Result<Time>
fn get_time(&self, pos: usize) -> Result<Time>
Returns the time value at the given position (time as milliseconds since midnight)
Sourcefn get_timestamp_ntz(&self, pos: usize, precision: u32) -> Result<TimestampNtz>
fn get_timestamp_ntz(&self, pos: usize, precision: u32) -> Result<TimestampNtz>
Returns the timestamp value at the given position (timestamp without timezone)
The precision is required to determine whether the timestamp value was stored in a compact representation (precision <= 3) or with nanosecond precision.
Sourcefn get_timestamp_ltz(&self, pos: usize, precision: u32) -> Result<TimestampLtz>
fn get_timestamp_ltz(&self, pos: usize, precision: u32) -> Result<TimestampLtz>
Returns the timestamp value at the given position (timestamp with local timezone)
The precision is required to determine whether the timestamp value was stored in a compact representation (precision <= 3) or with nanosecond precision.
Provided Methods
Sourcefn as_encoded_bytes(&self, _write_format: WriteFormat) -> Option<&[u8]>
fn as_encoded_bytes(&self, _write_format: WriteFormat) -> Option<&[u8]>
Returns encoded bytes if already encoded